==> react_image_annotate_ns_workflow-7.0.9.tgz: package/KeyframesSelectorSidebarBox/index.js <==
//  weak

import AddLocationIcon from "@mui/icons-material/AddLocation";
import TrashIcon from "@mui/icons-material/Delete";
import ReorderIcon from "@mui/icons-material/SwapVert";
import { Grid } from "@mui/material";
import * as colors from "@mui/material/colors";
import { grey } from "@mui/material/colors";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/styles";
import classnames from "classnames";
import React, { useMemo } from "react";
import getTimeString from "../KeyframeTimeline/get-time-string.js";
import styles from "../RegionSelectorSidebarBox/styles.js";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var KeyframeRow = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    cursor: "pointer",
    display: "flex",
    alignItems: "center",
    padding: 8,
    fontSize: 14,
    color: colors.grey[700],
    "&.current": {
      backgroundColor: colors.blue[100]
    },
    "&:hover": {
      backgroundColor: colors.grey[100]
    },
    "& .time": {
      flexGrow: 1,
      fontWeight: "bold",
      "& .regionCount": {
        marginLeft: 8,
        fontWeight: "normal",
        color: colors.grey[500]
      }
    },
    "& .trash": {
      "& .icon": {
        fontSize: 18,
        color: colors.grey[600],
        transition: "transform 80ms",
        "&:hover": {
          color: colors.grey[800],
          transform: "scale(1.25,1.25)"
        }
      }
    }
  };
});
var useStyles = makeStyles(function (theme) {
  return styles;
});
var HeaderSep = styled("div")(function (_ref2) {
  var theme = _ref2.theme;
  return {
    borderTop: "1px solid ".concat(grey[200]),
    marginTop: 2,
    marginBottom: 2
  };
});
var RowLayout = function RowLayout(_ref3) {
  var order = _ref3.order,
    classes = _ref3.classes,
    title = _ref3.title,
    trash = _ref3.trash;
  return /*#__PURE__*/React.createElement("div", {
    // onMouseEnter={() => changeMouseOver(true)}
    // onMouseLeave={() => changeMouseOver(false)}
    className: classnames(classes.row)
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, order), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 5
  }, title), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      textAlign: "right",
      paddingRight: 6
    }
  })), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, " "), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, trash)));
};
var KeyframesSelectorSidebarBox = function KeyframesSelectorSidebarBox(_ref4) {
  var currentVideoTime = _ref4.currentVideoTime,
    keyframes = _ref4.keyframes,
    onChangeVideoTime = _ref4.onChangeVideoTime,
    onDeleteKeyframe = _ref4.onDeleteKeyframe,
    onDeleteAllKeyframe = _ref4.onDeleteAllKeyframe;
  var classes = useStyles();
  var keyframeTimes = useMemo(function () {
    return Object.keys(keyframes).map(function (t) {
      return parseInt(t);
    });
  }, [Object.keys(keyframes).length]);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Keyframes",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(AddLocationIcon, {
      style: {
        color: colors.grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.container
  }, /*#__PURE__*/React.createElement(RowLayout, {
    classes: classes,
    order: /*#__PURE__*/React.createElement("div", {
      style: {
        textAlign: "right",
        paddingRight: 10
      }
    }, /*#__PURE__*/React.createElement(ReorderIcon, {
      className: "icon"
    })),
    title: /*#__PURE__*/React.createElement("div", {
      style: {
        paddingLeft: 10
      }
    }, "Timeline"),
    trash: /*#__PURE__*/React.createElement("div", {
      className: "trash"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick(e) {
        onDeleteAllKeyframe();
        e.stopPropagation();
      },
      className: "icon"
    }))
  }), /*#__PURE__*/React.createElement(HeaderSep, null), keyframeTimes.map(function (t, index) {
    var _keyframes$t;
    return /*#__PURE__*/React.createElement(RowLayout, {
      key: t,
      classes: classes,
      order: /*#__PURE__*/React.createElement("div", {
        style: {
          textAlign: "center"
        }
      }, "#", index + 1),
      title: /*#__PURE__*/React.createElement("div", {
        style: {
          paddingLeft: 10
        },
        className: currentVideoTime === t ? "current" : "",
        onClick: function onClick() {
          return onChangeVideoTime(t);
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "time"
      }, getTimeString(t, 2), /*#__PURE__*/React.createElement("span", {
        className: "regionCount"
      }, "\xA0(", (((_keyframes$t = keyframes[t]) === null || _keyframes$t === void 0 ? void 0 : _keyframes$t.regions) || []).length, ")"))),
      trash: /*#__PURE__*/React.createElement("div", {
        className: "trash"
      }, /*#__PURE__*/React.createElement(TrashIcon, {
        onClick: function onClick(e) {
          onDeleteKeyframe(t);
          e.stopPropagation();
        },
        className: "icon"
      }))
    })
    // <KeyframeRow
    //   fullWidth
    //   key={t}
    //   className={currentVideoTime === t ? "current" : ""}
    //   onClick={() => onChangeVideoTime(t)}
    // >
    //   <div className="time">
    //     {getTimeString(t, 2)}
    //     <span className="regionCount">
    //       ({(keyframes[t]?.regions || []).length})
    //     </span>
    //   </div>
    //   <div className="trash">
    //     <TrashIcon
    //       onClick={(e) => {
    //         onDeleteKeyframe(t)
    //         e.stopPropagation()
    //       }}
    //       className="icon"
    //     />
    //   </div>
    // </KeyframeRow>
    ;
  }))));
};

export default KeyframesSelectorSidebarBox;

==> react_image_annotate_ns_workflow-7.1.4.tgz: package/KeyframesSelectorSidebarBox/index.js <==
//  weak

import AddLocationIcon from "@mui/icons-material/AddLocation";
import TrashIcon from "@mui/icons-material/Delete";
import ReorderIcon from "@mui/icons-material/SwapVert";
import { Grid } from "@mui/material";
import * as colors from "@mui/material/colors";
import { grey } from "@mui/material/colors";
import { createTheme, styled, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/system";
import classnames from "classnames";
import React, { useMemo } from "react";
import getTimeString from "../KeyframeTimeline/get-time-string.js";
import styles from "../RegionSelectorSidebarBox/styles.js";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var KeyframeRow = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    cursor: "pointer",
    display: "flex",
    alignItems: "center",
    padding: 8,
    fontSize: 14,
    color: colors.grey[700],
    "&.current": {
      backgroundColor: colors.blue[100]
    },
    "&:hover": {
      backgroundColor: colors.grey[100]
    },
    "& .time": {
      flexGrow: 1,
      fontWeight: "bold",
      "& .regionCount": {
        marginLeft: 8,
        fontWeight: "normal",
        color: colors.grey[500]
      }
    },
    "& .trash": {
      "& .icon": {
        fontSize: 18,
        color: colors.grey[600],
        transition: "transform 80ms",
        "&:hover": {
          color: colors.grey[800],
          transform: "scale(1.25,1.25)"
        }
      }
    }
  };
});
var useStyles = makeStyles(function (theme) {
  return styles;
});
var HeaderSep = styled("div")(function (_ref2) {
  var theme = _ref2.theme;
  return {
    borderTop: "1px solid ".concat(grey[200]),
    marginTop: 2,
    marginBottom: 2
  };
});
var RowLayout = function RowLayout(_ref3) {
  var order = _ref3.order,
    classes = _ref3.classes,
    title = _ref3.title,
    trash = _ref3.trash;
  return /*#__PURE__*/React.createElement("div", {
    // onMouseEnter={() => changeMouseOver(true)}
    // onMouseLeave={() => changeMouseOver(false)}
    className: classnames(classes.row)
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, order), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 5
  }, title), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      textAlign: "right",
      paddingRight: 6
    }
  })), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, " "), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 1
  }, trash)));
};
var KeyframesSelectorSidebarBox = function KeyframesSelectorSidebarBox(_ref4) {
  var currentVideoTime = _ref4.currentVideoTime,
    keyframes = _ref4.keyframes,
    onChangeVideoTime = _ref4.onChangeVideoTime,
    onDeleteKeyframe = _ref4.onDeleteKeyframe,
    onDeleteAllKeyframe = _ref4.onDeleteAllKeyframe;
  var classes = useStyles();
  var keyframeTimes = useMemo(function () {
    return Object.keys(keyframes).map(function (t) {
      return parseInt(t);
    });
  }, [Object.keys(keyframes).length]);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "Keyframes",
    subTitle: "",
    icon: /*#__PURE__*/React.createElement(AddLocationIcon, {
      style: {
        color: colors.grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.container
  }, /*#__PURE__*/React.createElement(RowLayout, {
    classes: classes,
    order: /*#__PURE__*/React.createElement("div", {
      style: {
        textAlign: "right",
        paddingRight: 10
      }
    }, /*#__PURE__*/React.createElement(ReorderIcon, {
      className: "icon"
    })),
    title: /*#__PURE__*/React.createElement("div", {
      style: {
        paddingLeft: 10
      }
    }, "Timeline"),
    trash: /*#__PURE__*/React.createElement("div", {
      className: "trash"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      onClick: function onClick(e) {
        onDeleteAllKeyframe();
        e.stopPropagation();
      },
      className: "icon"
    }))
  }), /*#__PURE__*/React.createElement(HeaderSep, null), keyframeTimes.map(function (t, index) {
    var _keyframes$t;
    return /*#__PURE__*/React.createElement(RowLayout, {
      key: t,
      classes: classes,
      order: /*#__PURE__*/React.createElement("div", {
        style: {
          textAlign: "center"
        }
      }, "#", index + 1),
      title: /*#__PURE__*/React.createElement("div", {
        style: {
          paddingLeft: 10
        },
        className: currentVideoTime === t ? "current" : "",
        onClick: function onClick() {
          return onChangeVideoTime(t);
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "time"
      }, getTimeString(t, 2), /*#__PURE__*/React.createElement("span", {
        className: "regionCount"
      }, "\xA0(", (((_keyframes$t = keyframes[t]) === null || _keyframes$t === void 0 ? void 0 : _keyframes$t.regions) || []).length, ")"))),
      trash: /*#__PURE__*/React.createElement("div", {
        className: "trash"
      }, /*#__PURE__*/React.createElement(TrashIcon, {
        onClick: function onClick(e) {
          onDeleteKeyframe(t);
          e.stopPropagation();
        },
        className: "icon"
      }))
    })
    // <KeyframeRow
    //   fullWidth
    //   key={t}
    //   className={currentVideoTime === t ? "current" : ""}
    //   onClick={() => onChangeVideoTime(t)}
    // >
    //   <div className="time">
    //     {getTimeString(t, 2)}
    //     <span className="regionCount">
    //       ({(keyframes[t]?.regions || []).length})
    //     </span>
    //   </div>
    //   <div className="trash">
    //     <TrashIcon
    //       onClick={(e) => {
    //         onDeleteKeyframe(t)
    //         e.stopPropagation()
    //       }}
    //       className="icon"
    //     />
    //   </div>
    // </KeyframeRow>
    ;
  }))));
};

export default KeyframesSelectorSidebarBox;
